@@ -25,28 +25,51 @@ class Customer(object):
 
     def __init__(self, name, product_ese=False, **kwargs):
         self.name = name.lower()
-        url = core.database_url(**FUPDB_CREDENTIALS)
-        with records.Database(url) as db:
-            if kwargs:
-                self.table_customer = kwargs.get('table_customer')
-                self.table_cdr = kwargs.get('table_cdr')
-            else:
-                self.table_customer = 'customer'
-                self.table_cdr = 'cdr'
-            sql = (
-                "SELECT refnum, product FROM {}"
-                " WHERE name=:name"
-                ).format(self.table_customer)
-            rows = db.query(sql, name=self.name)
-            row = rows.first()
-            if not row:
-                raise ValueError(
-                    "Le client {name} n'existe pas".format(name=name)
-                    )
-            else:
-                self.product = product.Product(row.product)
-                self.refnum = row.refnum
-            LOGS.logger.info(self.product)
+        # url = core.database_url(**FUPDB_CREDENTIALS)
+        # with records.Database(url) as db:
+        #     if kwargs:
+        #         self.table_customer = kwargs.get('table_customer')
+        #         self.table_cdr = kwargs.get('table_cdr')
+        #     else:
+        #         self.table_customer = 'customer'
+        #         self.table_cdr = 'cdr'
+        #     sql = (
+        #         "SELECT refnum, product FROM {}"
+        #         " WHERE name=:name"
+        #         ).format(self.table_customer)
+        #     rows = db.query(sql, name=self.name)
+        #     row = rows.first()
+        #     if not row:
+        #         raise ValueError(
+        #             "Le client {name} n'existe pas".format(name=name)
+        #             )
+        #     else:
+        #         self.product = product.Product(row.product)
+        #         self.refnum = row.refnum
+        #     LOGS.logger.info(self.product)
+        if kwargs:
+            self.table_customer = kwargs.get('table_customer')
+            self.table_cdr = kwargs.get('table_cdr')
+        else:
+            self.table_customer = 'customer'
+            self.table_cdr = 'cdr'
+        conn = core.connexion(**FUPDB_CREDENTIALS)
+        cursor = conn.cursor()
+        sql = (
+            "select refnum, product"
+            " from {} where name = %s"
+            ).format(self.table_customer)
+        cursor.execute(sql, (self.name,))
+        row = cursor.fetchone()
+        LOGS.logger.info("Resutlt: {}".format(row))
+        if not row:
+            raise ValueError(
+                "Le client {name} n'existe pas".format(name=name)
+                )
+        else:
+            self.product = product.Product(row[1])
+            self.refnum = row[0]
+        LOGS.logger.info(self.product)
 
     def __repr__(self):
         return '<Customer {name}>'.format(name=self.name)
