@@ -262,6 +262,7 @@ class Product_GP(object):
                 ),
             auth=(username, ''),
             json={
+                'sender_id': 'Blueline',
                 'message': sms,
                 'msisdn': phonenumber
                 }
@@ -556,18 +557,18 @@ class Product_GP(object):
             )
         # date_try_minus = datetime.strftime(date_try_minus, '%d/%m/%Y')
         # date_alert_2 = datetime.strftime(today, '%d/%m/%Y')
-        click.echo('notif_mail date_try_minus {}'.format(
-            str(date_try_minus)
-            ))
-        click.echo('notif_sms date du jour {}'.format(
-            str(date_alert_2)
-            ))
-        click.echo('last_notification_email_date{}'.format(
-            str(last_notification_email_date)
-            ))
-        click.echo('last_notification_sms_date {}'.format(
-            str(last_notification_sms_date)
-            ))
+        # click.echo('notif_mail date_try_minus {}'.format(
+        #    str(date_try_minus)
+        #    ))
+        # click.echo('notif_sms date du jour {}'.format(
+        #    str(date_alert_2)
+        #    ))
+        # click.echo('last_notification_email_date{}'.format(
+        #    str(last_notification_email_date)
+        #    ))
+        # click.echo('last_notification_sms_date {}'.format(
+        #    str(last_notification_sms_date)
+        #    ))
         condition_conso = (
             not last_notification_email_conso
             and
